=======
Credits
=======

Development Leads
-----------------

* `Moritz E. Beber <morbeb@biosustain.dtu.dk>`_
* `Christian Lieven <clie@biosustain.dtu.dk>`_

Contributors
------------

* `Nikolaus Sonnenschein <niso@biosustain.dtu.dk>`_
* `Siddharth Chauhan  <sidcha@biosustain.dtu.dk>`_
* `Ali Kaafarani <alikaa@biosustain.dtu.dk>`_
* `Danny Dannaher  <dandann@biosustain.dtu.dk>`_
